@@ -1,4 +1,4 @@
-from typing import Union, NewType, List, Dict, Final
+from typing import Union, NewType, List, Dict
 
 import k3d
 import numpy as np
@@ -8,7 +8,7 @@ from .jointset import JointSet
 
 Color = NewType('Color', Union[str, int])
 
-DEFAULT_COLORS: Final[Dict[str, int]] = {
+DEFAULT_COLORS: Dict[str, int] = {
     'red': 0xFF0000, 'green': 0x00FF00,  'blue': 0x0000FF,
     'yellow': 0xFFFF00, 'teal': 0x00FFFF, 'purple': 0xFF00FF,
     'white': 0xFFFFFF, 'black': 0x000000
@@ -86,7 +86,7 @@ class Skeleton:
         skeleton_joint_colors = self.get_joint_colors()
         return k3d.points(
             positions=self.joint_coordinates, point_size=self.part_size,
-            shader='dot', colors=skeleton_joint_colors
+            shader='3d', colors=skeleton_joint_colors
         )
 
     def get_joint_lines(self) -> List[Line]:
@@ -110,6 +110,6 @@ class Skeleton:
     @staticmethod
     def __create_line_between_joints(start: float, end: float, width: float, color: int) -> Line:
         return k3d.line(
-            vertices=[start, end], shader='simple',
+            vertices=[start, end], shader='thick',
             width=width, color=color
         )
